.. tkmilan documentation master file, created by
   sphinx-quickstart on Thu Aug  5 12:03:06 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

tkmilan
=======

This is documentation for the tkmilan module.

.. todo:: Include a hero image here, a screenshot of the showcase.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   development

   summary
   api

Other Pages
-----------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. todo:: Include these links on the regular TOC

Metadata
--------

Current Documentation Version: |version|.
Built in |today|.

.. only:: debug

   Current Release: |release|
